@@ -35,7 +35,7 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_BH1750.git"
 from time import sleep
 from struct import unpack_from
 from micropython import const
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 
 
 _BH1750_DEVICE_ID = 0xE1  # Correct content of WHO_AM_I register
